@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -73,6 +73,15 @@ public final class Autoboxing {
         return Integer.valueOf(i);
     }
 
+    /**
+     * Short method name for unboxing an {@link Integer} object.
+     * @param integer {@link Integer} to unbox.
+     * @return the int value
+     */
+    public static int i(final Integer integer) {
+        return integer.intValue();
+    }
+
     /**
      * Short method name for {@link Long#valueOf(long)} that uses cached instances for small values of long.
      * @param l long value to be converted to a Long object.
@@ -82,6 +91,10 @@ public final class Autoboxing {
         return Long.valueOf(l);
     }
 
+    public static long l(Long l) {
+        return l.longValue();
+    }
+
     /**
      * Short method name for {@link Boolean#valueOf(boolean)} that uses cached instances.
      * @param b boolean value to be converted to a Boolean object.
@@ -100,6 +113,10 @@ public final class Autoboxing {
         return Float.valueOf(f);
     }
 
+    public static float f(Float f) {
+        return f.floatValue();
+    }
+
     /**
      * Converts an int-array into an Integer-array.
      * @param intArray int[] to be converted to Integer[]
@@ -128,13 +145,13 @@ public final class Autoboxing {
 
     /**
      * Converts an Integer-list into an int-array.
-     * @param integerList List of Integers to be converted to int[]
+     * @param integerCollection List of Integers to be converted to int[]
      * @return int[]
      */
-    public static int[] I2i(Collection<Integer> integerList) {
-        int[] intArray = new int[integerList.size()];
+    public static int[] I2i(Collection<Integer> integerCollection) {
+        int[] intArray = new int[integerCollection.size()];
         int pos = 0;
-        for (Integer i : integerList) {
+        for (Integer i : integerCollection) {
             intArray[pos++] = i.intValue();
         }
         return intArray;
